@@ -1,4 +1,3 @@
-
 #if HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -10,12 +9,7 @@
 #include <stddef.h>
 
 #ifndef _MSC_VER
-# if defined(__sun) || defined(__sun__)
-#  include <sys/inttypes.h>
-#  define PTRDIFF_MAX INT_MAX
-# else
-#  include <stdint.h>
-# endif
+#include <stdint.h>
 #else
 #ifdef _WIN64
 #define PTRDIFF_MAX _I64_MAX
@@ -247,9 +241,9 @@ yaml_string_join(
         (string).pointer[offset] <= (yaml_char_t) 'f') ?                        \
        ((string).pointer[offset] - (yaml_char_t) 'a' + 10) :                    \
        ((string).pointer[offset] - (yaml_char_t) '0'))
- 
+
 #define AS_HEX(string)  AS_HEX_AT((string),0)
- 
+
 /*
  * Check if the character is ASCII.
  */
@@ -662,4 +656,3 @@ yaml_queue_extend(void **start, void **head, void **tail, void **end);
      (node).data.mapping.pairs.end = (node_pairs_end),                          \
      (node).data.mapping.pairs.top = (node_pairs_start),                        \
      (node).data.mapping.style = (node_style))
-
